#ifndef NT2_INCLUDE_FUNCTIONS_CAUINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAUINV_HPP_INCLUDED

#include <nt2/statistics/include/functions/cauinv.hpp>

#endif
